GroupEncoder

Trait GroupEncoder 

pub trait GroupEncoder {
    type Entry<'a>
       where Self: 'a;

    // Required methods
    fn count(&self) -> u16;
    fn next_entry(&mut self) -> Option<Self::Entry<'_>>;
}
Trait for group encoders.

Group encoders handle the encoding of repeating groups within messages.

Required Associated Types

type Entry<'a> where Self: 'a

The entry encoder type for this group.

Required Methods

fn count(&self) -> u16

Returns the number of entries that will be written.

fn next_entry(&mut self) -> Option<Self::Entry<'_>>

Begins encoding a new entry.

Returns

An entry encoder for the new entry.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors