VarDataHeader8

Struct VarDataHeader8 

#[repr(C, packed(1))]
pub struct VarDataHeader8 { pub length: u8, }
Variable-length data header with u8 length (1 byte).

Fields

length: u8

Length of the variable data in bytes.

Implementations

Source

impl VarDataHeader8

pub const ENCODED_LENGTH: usize = 1

Encoded length of the var data header in bytes.

pub const fn new(length: u8) -> Self

Creates a new var data header with the specified length.

pub fn wrap<B: ReadBuffer + ?Sized>(buffer: &B, offset: usize) -> Self

Wraps a buffer and decodes the var data header at the given offset.

pub fn encode<B: WriteBuffer + ?Sized>(&self, buffer: &mut B, offset: usize)

Encodes the var data header to the buffer at the given offset.